==> zzyj-laborservice-impl-3.0.0-20241213.054421-53-sources.jar: com/ejianc/business/itax/bean/SalaryEntity.java <==
package com.ejianc.business.itax.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.itax.bean.SalaryDetailEntity;
/**
 * 工人工资上传
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_itax_salary")
public class SalaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 劳务队长人姓名
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="money_sum")
    private BigDecimal moneySum; // 本次发放总金额
    @TableField(value="bill_time")
    private Date billTime; // 上传日期
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID
    @TableField(value="submit_time")
    private Date submitTime; // 生效时间

    @TableField(exist=false)
    @SubEntity(serviceName="salaryDetailService")
    private List<SalaryDetailEntity> salaryDetailList = new ArrayList<>(); // 工人工资上传明细


    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoneySum() {
        return moneySum;
    }

    public void setMoneySum(BigDecimal moneySum) {
        this.moneySum = moneySum;
    }
    public Date getBillTime() {
        return billTime;
    }

    public void setBillTime(Date billTime) {
        this.billTime = billTime;
    }
    

    public List<SalaryDetailEntity> getSalaryDetailList() {
        return salaryDetailList;
    }

    public void setSalaryDetailList(List<SalaryDetailEntity> salaryDetailList) {
        this.salaryDetailList = salaryDetailList;
    }
}

==> zzyj-laborservice-impl-3.0.0-20250402.072543-82-sources.jar: com/ejianc/business/itax/bean/SalaryEntity.java <==
package com.ejianc.business.itax.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.itax.bean.SalaryDetailEntity;
/**
 * 工人工资上传
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_itax_salary")
public class SalaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 劳务队长人姓名
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="money_sum")
    private BigDecimal moneySum; // 本次发放总金额
    @TableField(value="bill_time")
    private Date billTime; // 上传日期
    @TableField(value="create_user_id")
    private Long createUserId; // 创建人ID
    @TableField(value="submit_time")
    private Date submitTime; // 生效时间

    @TableField(exist=false)
    @SubEntity(serviceName="salaryDetailService")
    private List<SalaryDetailEntity> salaryDetailList = new ArrayList<>(); // 工人工资上传明细
    @TableField(value="expend_contract_id")
    private Long expendContractId; // 支出合同id
    @TableField(value="expend_contract_name")
    private String expendContractName; // 支出合同名称
    @TableField(value="expend_contract_code")
    private String expendContractCode; // 支出合同编号
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目管理部名称
    @TableField(value="is_error")
    private Integer isError; // 是否有错误数据
    @TableField(value="this_month_itax_total")
    private BigDecimal thisMonthItaxTotal; // 计算个税
    @TableField(value="this_month_itax_yj_total")
    private BigDecimal thisMonthItaxYjTotal; // 已交个税
    @TableField(value="last_month_state")
    private String lastMonthState; // 上月申报状态

    public Integer getIsError() {
        return isError;
    }

    public void setIsError(Integer isError) {
        this.isError = isError;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getExpendContractId() {
        return expendContractId;
    }

    public void setExpendContractId(Long expendContractId) {
        this.expendContractId = expendContractId;
    }

    public String getExpendContractName() {
        return expendContractName;
    }

    public void setExpendContractName(String expendContractName) {
        this.expendContractName = expendContractName;
    }

    public String getExpendContractCode() {
        return expendContractCode;
    }

    public void setExpendContractCode(String expendContractCode) {
        this.expendContractCode = expendContractCode;
    }

    public Date getSubmitTime() {
        return submitTime;
    }

    public void setSubmitTime(Date submitTime) {
        this.submitTime = submitTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoneySum() {
        return moneySum;
    }

    public void setMoneySum(BigDecimal moneySum) {
        this.moneySum = moneySum;
    }
    public Date getBillTime() {
        return billTime;
    }

    public void setBillTime(Date billTime) {
        this.billTime = billTime;
    }
    

    public List<SalaryDetailEntity> getSalaryDetailList() {
        return salaryDetailList;
    }

    public void setSalaryDetailList(List<SalaryDetailEntity> salaryDetailList) {
        this.salaryDetailList = salaryDetailList;
    }

    public BigDecimal getThisMonthItaxTotal() {
        return thisMonthItaxTotal;
    }

    public void setThisMonthItaxTotal(BigDecimal thisMonthItaxTotal) {
        this.thisMonthItaxTotal = thisMonthItaxTotal;
    }

    public BigDecimal getThisMonthItaxYjTotal() {
        return thisMonthItaxYjTotal;
    }

    public void setThisMonthItaxYjTotal(BigDecimal thisMonthItaxYjTotal) {
        this.thisMonthItaxYjTotal = thisMonthItaxYjTotal;
    }

    public String getLastMonthState() {
        return lastMonthState;
    }

    public void setLastMonthState(String lastMonthState) {
        this.lastMonthState = lastMonthState;
    }
}
